summaryrefslogtreecommitdiffstats
path: root/src/k3bfiletreecombobox.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:29:52 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:29:52 -0600
commitef5831dd5c8811c94c9b1bc1377a90174d17c82c (patch)
tree32b4c7307b74026be725950a33d6ec56d0561b3f /src/k3bfiletreecombobox.cpp
parentdb733144770616f45d2d6e89bd3c424538a9fd92 (diff)
downloadk3b-ef5831dd5c8811c94c9b1bc1377a90174d17c82c.tar.gz
k3b-ef5831dd5c8811c94c9b1bc1377a90174d17c82c.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'src/k3bfiletreecombobox.cpp')
-rw-r--r--src/k3bfiletreecombobox.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/k3bfiletreecombobox.cpp b/src/k3bfiletreecombobox.cpp
index a4b3d3a..62e4936 100644
--- a/src/k3bfiletreecombobox.cpp
+++ b/src/k3bfiletreecombobox.cpp
@@ -29,7 +29,7 @@
#include <tqheader.h>
#include <tqevent.h>
#include <tqpainter.h>
-#include <tqpalette.h>
+#include <palette.h>
#include <tqdrawutil.h>
#include <tqdir.h>
@@ -154,8 +154,8 @@ void K3bFileTreeComboBox::popup()
// code mainly from qcombobox.cpp
m_fileTreeView->triggerUpdate();
- int w = TQMAX( m_fileTreeView->tqsizeHint().width(), width() );
- int h = m_fileTreeView->tqsizeHint().height();
+ int w = TQMAX( m_fileTreeView->sizeHint().width(), width() );
+ int h = m_fileTreeView->sizeHint().height();
TQRect screen = TQApplication::desktop()->availableGeometry( this );
int sx = screen.x(); // screen pos
int sy = screen.y();
@@ -198,7 +198,7 @@ void K3bFileTreeComboBox::popdown()
{
m_fileTreeView->hide();
d->poppedUp = false;
- tqrepaint(); // tqrepaint the arrow
+ repaint(); // repaint the arrow
}
@@ -276,7 +276,7 @@ bool K3bFileTreeComboBox::eventFilter( TQObject* o, TQEvent* e )
if ( !TQT_TQRECT_OBJECT(m_fileTreeView->rect()).contains( me->pos() ) ) {
TQRect arrowRect = tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this,
TQStyle::SC_ComboBoxArrow);
- arrowRect = TQStyle::tqvisualRect(arrowRect, this);
+ arrowRect = TQStyle::visualRect(arrowRect, this);
// Correction for motif style, where arrow is smaller
// and thus has a rect that doesn't fit the button.
@@ -310,7 +310,7 @@ void K3bFileTreeComboBox::mousePressEvent( TQMouseEvent* e )
TQRect arrowRect = tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this,
TQStyle::SC_ComboBoxArrow);
- arrowRect = TQStyle::tqvisualRect(arrowRect, this);
+ arrowRect = TQStyle::visualRect(arrowRect, this);
// Correction for motif style, where arrow is smaller
// and thus has a rect that doesn't fit the button.
@@ -318,7 +318,7 @@ void K3bFileTreeComboBox::mousePressEvent( TQMouseEvent* e )
if ( arrowRect.contains( e->pos() ) ) {
popup();
- tqrepaint( FALSE );
+ repaint( FALSE );
}
}
@@ -339,7 +339,7 @@ void K3bFileTreeComboBox::paintEvent( TQPaintEvent* )
// we only need this since there is no way to change the status of the arrow-button
TQPainter p( this );
- const TQColorGroup & g = tqcolorGroup();
+ const TQColorGroup & g = colorGroup();
p.setPen(g.text());
TQStyle::SFlags flags = TQStyle::Style_Default;
@@ -356,7 +356,7 @@ void K3bFileTreeComboBox::paintEvent( TQPaintEvent* )
// bool reverse = TQApplication::reverseLayout();
- tqstyle().tqdrawComplexControl( TQStyle::CC_ComboBox, &p, this, rect(), g,
+ tqstyle().drawComplexControl( TQStyle::CC_ComboBox, &p, this, rect(), g,
flags, TQStyle::SC_All,
(d->poppedUp ?
TQStyle::SC_ComboBoxArrow :
@@ -364,7 +364,7 @@ void K3bFileTreeComboBox::paintEvent( TQPaintEvent* )
TQRect re = tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this,
TQStyle::SC_ComboBoxEditField );
- re = TQStyle::tqvisualRect(re, this);
+ re = TQStyle::visualRect(re, this);
p.setClipRect( re );
// TQListBoxItem * item = listBox()->item( 0 );
@@ -380,7 +380,7 @@ void K3bFileTreeComboBox::paintEvent( TQPaintEvent* )
const TQPixmap *pix = item->pixmap();
if ( pix ) {
p.fillRect( re.x(), re.y(), pix->width() + 4, re.height(),
- tqcolorGroup().brush( TQColorGroup::Base ) );
+ colorGroup().brush( TQColorGroup::Base ) );
p.drawPixmap( re.x() + 2, re.y() +
( re.height() - pix->height() ) / 2, *pix );
}